@@ -19,12 +19,14 @@
 
 #include <config.h>
 
-#include <stdio.h>
+#ifdef HAVE_STDIO_H
+# include <stdio.h>
+#endif
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
 
-#if defined(HAVE_SYS_SYSINFO_H)
+#ifdef HAVE_SYS_SYSINFO_H
 #include <sys/sysinfo.h>
 
 #if defined(__CYGWIN__)
