@@ -1,6 +1,6 @@
 /* randomize:  Randomizes lines from a file or from stdin.
 
-   Copyright (C) 2004-2020 by Brian Lindholm.
+   Copyright (C) 2004-2021 by Brian Lindholm.
    This file is part of the littleutils utility set.
 
    The randomize utility is free software; you can redistribute it and/or
@@ -20,27 +20,33 @@
 #include <config.h>
 
 #include <fcntl.h>
-#include <stdio.h>
+#ifdef HAVE_STDIO_H
+# include <stdio.h>
+#endif
 #ifdef HAVE_STDLIB_H
 # include <stdlib.h>
 #endif
 #ifdef HAVE_STRING_H
 # include <string.h>
 #endif
-#include <time.h>
+#ifdef HAVE_SYS_RANDOM_H
+# include <sys/random.h>
+#endif
 #ifdef HAVE_SYS_STAT_H
 # include <sys/stat.h>
 #endif
 
-#ifdef HAVE_GETOPT_H
-# include <getopt.h>
-#endif
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 # define OPTEND -1
 #else
 # define OPTEND EOF
 #endif
+#ifdef HAVE_GETOPT_H
+# include <getopt.h>
+#endif
+
+#include "rand_funcs.h"
 
 #ifdef __MINGW32__
 extern int getopt (int argc, char * const *argv, const char *optstring);
@@ -73,66 +79,6 @@ help (FILE *where)
 }
 
 
-/* random functions */
-
-static void
-rand_seed ()
-{
-  int URANDOM, urandom_worked = 1;
-  ssize_t bytes;
-  time_t junk;
-  unsigned short seed[3];
-
-  /* pre-populate arracy for seed using /dev/urandom */
-  URANDOM = open("/dev/urandom", O_RDONLY);
-  if (URANDOM < 0) {
-    urandom_worked = 0;
-  }
-  else {
-    /* use read instead of buffered fread to avoid grabbing extra bytes */
-    bytes = read(URANDOM, seed, sizeof seed);
-    if (bytes < 6) {
-      urandom_worked = 0;
-    }
-  }
-  close(URANDOM);
-
-  /* fall back to time and PID combo if /dev/urandom failed */
-  if (urandom_worked == 0) {
-    (void) time (&junk);
-    seed[0] = (unsigned short) (junk & 0xFFFF);
-    seed[1] = (unsigned short) (getpid () & 0xFFFF);
-    seed[2] = (unsigned short) ((junk >> 16) & 0xFFFF);
-  }
-
-  /* initialize random number generator seed */
-#ifdef HAVE_LRAND48
-  (void) seed48 (seed);
-#elif defined(HAVE_RANDOM)
-  srandom (((unsigned int) seed[0] << 16) + (unsigned int) seed[1]);
-#else
-  srand (((unsigned int) seed[0] << 16) + (unsigned int) seed[1]);
-#endif
-}
-
-static size_t
-rand_int (size_t n)
-{
-  size_t x;
-
-#if defined(HAVE_LRAND48)
-  x = (size_t) ((double) n * drand48 ());
-#elif defined(HAVE_RANDOM)
-  x = (size_t) ((double) n * ((double) random () / (double) 2147483648.0));
-#else
-  x = (size_t) ((double) n * ((double) rand () / ((double) RAND_MAX + 1.0)));
-#endif
-  if (x > (n - 1))
-    x = 0;
-  return (x);
-}
-
-
 /* read stdin into a buffer allocated here, returning number of bytes read */
 
 static size_t
@@ -210,8 +156,7 @@ prep_buffer (char **buffer, size_t size)
    from file */
 
 static size_t
-load_file (char *buffer, char *filename, size_t size, size_t index,
-  char delimiter)
+load_file (char *buffer, char *filename, size_t size, size_t index, char delimiter)
 {
   size_t qty_read;
   FILE *input_file;
@@ -375,7 +320,6 @@ main (int argc, char *argv[])
       rand_seed ();
 
       /* shuffle the list twice */
-
       for (k = 0; k < 2; k++)
         for (i = 0; i < delimiter_qty; i++)
           {
