@@ -1,40 +1,41 @@
 /* Declarations of functions and data types used for SHA1 sum
    library functions.
-   Copyright (C) 2000-2001, 2003, 2005-2006, 2008-2018 Free Software
+   Copyright (C) 2000-2001, 2003, 2005-2006, 2008-2023 Free Software
    Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify it
-   under the terms of the GNU General Public License as published by the
-   Free Software Foundation; either version 3, or (at your option) any
-   later version.
+   This file is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation; either version 2.1 of the
+   License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, see <https://www.gnu.org/licenses/>.  */
+   You should have received a copy of the GNU Lesser General Public License
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
-/* Modifications for partial file reads by Brian Lindholm, 2004-2021.  */
+/* Modifications for partial file reads by Brian Lindholm, 2004-2022.  */
 
 
 #ifndef SHA1_H
-#define SHA1_H 1
+# define SHA1_H 1
 
 #include <config.h>
 
-#if HAVE_INTTYPES_H
-# include <inttypes.h>
+#if HAVE_STDIO_H
+# include <stdio.h>
 #endif
 #if HAVE_STDINT_H || _LIBC
 # include <stdint.h>
 #endif
-#ifdef HAVE_STDIO_H
-# include <stdio.h>
-#endif
 
-#define SHA1_DIGEST_SIZE 20
+# ifdef __cplusplus
+extern "C" {
+# endif
+
+# define SHA1_DIGEST_SIZE 20
 
 /* Structure to save state of computation between the single steps.  */
 struct sha1_ctx
@@ -71,20 +72,21 @@ extern void sha1_process_bytes (const void *buffer, size_t len,
    in first 20 bytes following RESBUF.  The result is always in little
    endian byte order, so that a byte-wise output yields to the wanted
    ASCII representation of the message digest.  */
-extern void *sha1_finish_ctx (struct sha1_ctx *ctx, void *resbuf);
+extern void *sha1_finish_ctx (struct sha1_ctx *ctx, void *restrict resbuf);
 
 
 /* Put result from CTX in first 20 bytes following RESBUF.  The result is
    always in little endian byte order, so that a byte-wise output yields
    to the wanted ASCII representation of the message digest.  */
-extern void *sha1_read_ctx (const struct sha1_ctx *ctx, void *resbuf);
+extern void *sha1_read_ctx (const struct sha1_ctx *ctx, void *restrict resbuf);
 
 
 /* Compute SHA1 message digest for LEN bytes beginning at BUFFER.  The
    result is always in little endian byte order, so that a byte-wise
    output yields to the wanted ASCII representation of the message
    digest.  */
-extern void *sha1_buffer (const char *buffer, size_t len, void *resblock);
+extern void *sha1_buffer (const char *buffer, size_t len,
+                          void *restrict resblock);
 
 
 /* Compute SHA1 message digest for bytes read from STREAM.
@@ -96,4 +98,15 @@ extern void *sha1_buffer (const char *buffer, size_t len, void *resblock);
 extern int sha1_stream (FILE *stream, void *resblock, off_t readbytes);
 
 
+# ifdef __cplusplus
+}
+# endif
+
 #endif
+
+/*
+ * Hey Emacs!
+ * Local Variables:
+ * coding: utf-8
+ * End:
+ */
