@@ -1,44 +1,40 @@
 /* sha512.c - Functions to compute SHA512 and SHA384 message digest of files or
    memory blocks according to the NIST specification FIPS-180-2.
 
-   Copyright (C) 2005-2006, 2008-2018 Free Software Foundation, Inc.
+   Copyright (C) 2005-2006, 2008-2023 Free Software Foundation, Inc.
 
-   This program is free software: you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 3 of the License, or
-   (at your option) any later version.
+   This file is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation; either version 2.1 of the
+   License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
+   You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Written by David Madore, considerably copypasting from Scott G. Miller's
    sha1.c.  Modifications for portability and partial file reads by Brian
-   Lindholm, 2007-2021.  */
+   Lindholm, 2007-2023.  */
+
 
 #include <config.h>
 
+/* Specification.  */
+#include "sha512.h"
+
 #ifdef HAVE_STDALIGN_H
 # include <stdalign.h>
 #endif
 #ifdef HAVE_STDINT_H
 # include <stdint.h>
 #endif
-#ifdef HAVE_STDLIB_H
-# include <stdlib.h>
-#endif
 #ifdef HAVE_STRING_H
 # include <string.h>
 #endif
-#ifdef HAVE_SYS_TYPES_H
-# include <sys/types.h>
-#endif
-
-#include "sha512.h"
 
 #ifdef WORDS_BIGENDIAN
 # define SWAP(n) (n)
@@ -59,11 +55,6 @@
 # endif
 #endif
 
-#define BLOCKSIZE 32768
-#if BLOCKSIZE % 128 != 0
-# error "invalid BLOCKSIZE"
-#endif
-
 /* This array contains the bytes used to pad the buffer to the next
    128-byte boundary.  */
 static const unsigned char fillbuf[128] = { 0x80, 0 /* , 0, 0, ...  */ };
@@ -184,112 +175,6 @@ sha384_finish_ctx (struct sha512_ctx *ctx, void *resbuf)
   return sha384_read_ctx (ctx, resbuf);
 }
 
-/* Compute message digest for bytes read from STREAM using algorithm ALG.
-   Write the message digest into RESBLOCK, which contains HASHLEN bytes.  The
-   initial and finishing operations are INIT_CTX and FINISH_CTX.  Return zero
-   if and only if successful.  Readbytes == -1 implies whole file.  */
-
-static int
-shaxxx_stream (FILE *stream, char const *alg, void *resblock, off_t readbytes,
-               ssize_t hashlen, void (*init_ctx) (struct sha512_ctx *),
-               void *(*finish_ctx) (struct sha512_ctx *, void *))
-{
-  char *buffer = malloc (BLOCKSIZE + 72);
-  if (!buffer)
-    return 1;
-
-  /* Initialize the computation context.  */
-  struct sha512_ctx ctx;
-  init_ctx (&ctx);
-  size_t sum, target;
-  off_t total = 0;
-
-  /* Jump to end for readbytes == 0.  */
-  if (readbytes == 0)
-    {
-      sum = 0;
-      goto process_partial_block;
-    }
-
-  /* Iterate over full file contents.  */
-  while (1)
-    {
-      /* We read the file in blocks of BLOCKSIZE bytes.  One call of the
-         computation function processes the whole buffer so that with the
-         next round of the loop another block can be read.  */
-      size_t n;
-      if ((readbytes < 0) || ((readbytes - total) > (off_t) BLOCKSIZE))
-        target = (size_t) BLOCKSIZE;
-      else
-        target = (size_t) (readbytes - total);
-      sum = 0;
-
-      /* Read block.  Take care for partial reads.  */
-      while (1)
-        {
-          /* Either process a partial fread() from this loop,
-             or the fread() in afalg_stream may have gotten EOF.
-             We need to avoid a subsequent fread() as EOF may
-             not be sticky.  For details of such systems, see:
-             https://sourceware.org/bugzilla/show_bug.cgi?id=1190  */
-          if (((off_t) sum >= target) || feof (stream))
-            goto process_partial_block;
-
-          n = fread (buffer + sum, 1, target - sum, stream);
-          sum += n;
-
-          if (sum == BLOCKSIZE)
-            break;
-
-          if (n == 0)
-            {
-              /* Check for the error flag IFF N == 0, so that we don't
-                 exit the loop after a partial read due to e.g., EAGAIN
-                 or EWOULDBLOCK.  */
-              if (ferror (stream))
-                {
-                  free (buffer);
-                  return 1;
-                }
-              goto process_partial_block;
-            }
-        }
-      total += (off_t) sum;
-
-      /* Process buffer with BLOCKSIZE bytes.  Note that
-                        BLOCKSIZE % 128 == 0
-       */
-      sha512_process_block (buffer, BLOCKSIZE, &ctx);
-    }
-
- process_partial_block:;
-
-  /* Process any remaining bytes.  */
-  if (sum > 0)
-    sha512_process_bytes (buffer, sum, &ctx);
-
-  /* Construct result in desired memory.  */
-  finish_ctx (&ctx, resblock);
-  free (buffer);
-  return 0;
-}
-
-int
-sha512_stream (FILE *stream, void *resblock, off_t readbytes)
-{
-  return shaxxx_stream (stream, "sha512", resblock, readbytes,
-                        SHA512_DIGEST_SIZE, sha512_init_ctx,
-                        sha512_finish_ctx);
-}
-
-int
-sha384_stream (FILE *stream, void *resblock, off_t readbytes)
-{
-  return shaxxx_stream (stream, "sha384", resblock, readbytes,
-                        SHA384_DIGEST_SIZE, sha384_init_ctx,
-                        sha384_finish_ctx);
-}
-
 /* Compute SHA512 message digest for LEN bytes beginning at BUFFER.  The
    result is always in little endian byte order, so that a byte-wise
    output yields to the wanted ASCII representation of the message
@@ -596,3 +481,10 @@ sha512_process_block (const void *buffer, size_t len, struct sha512_ctx *ctx)
       h = ctx->state[7] = u64plus (ctx->state[7], h);
     }
 }
+
+/*
+ * Hey Emacs!
+ * Local Variables:
+ * coding: utf-8
+ * End:
+ */
